@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.083'; 
+our $VERSION = '1.0832'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -929,12 +929,11 @@ __END__
 
 =pod
 
-
 =head1 NAME
 
 Reddit::Client - A Perl wrapper for the Reddit API.
 
-B<The official documentation can be found at> L<http://redditclient.readthedocs.org/en/latest/>. What follows below might not be wrong but is not guaranteed to be right, and the likelihood of it being wrong increases with time.
+B<The official documentation can be found at> L<http://redditclient.readthedocs.org/en/latest/>. What follows below might not be wrong but is not guaranteed to be right.
 
 =head1 SYNOPSIS
 
@@ -1023,16 +1022,18 @@ Two notes about methods that return lists of things:
 
 1. All methods that return lists of things return them as a Perl _list_-- that is, a reference to an anonymous array. In practice this means that you get at the values with `@$array` instead of `@array`.
 
-2. All methods that return lists of things accept three optional parameters: `limit`, `before`, and `after`. You may recognize them from your address bar when viewing pages after the front page. `limit` defaults to 25, maximum 100. If `limit`  is present but false, this is interpreted as "no limit" and the max is returned.
+2. All methods that return lists of things accept three optional parameters: `limit`, `before`, and `after`. You may recognize them from your address bar when viewing pages after the front page. 
 
 
- B<limit> I<integer> How many things to return. Default 25, maximum 100. If `limit`  is present but false, this is interpreted as "no limit" and the max is returned.
+B<limit> I<integer> How many things to return. Default 25, maximum 100. If `limit` is present but false, this is interpreted as "no limit" and the max is returned.
 
- B<before> I<fullname> Return results that occur before `fullname`. 
+B<before> I<fullname> Return results that occur before `fullname`. Used for pagination.
 
- B<after> I<fullname> Return results that occur after `fullname`.
+B<after> I<fullname> Return results that occur after `fullname`. Used for pagination. 
 
 
+=head1 Methods
+
 =over
 
 =item delete 
@@ -1044,17 +1045,20 @@ Delete a post or comment.
 =item edit_wiki
 
     edit_wiki ( subreddit => $subreddit, page => $page, content => $content,
-				[ previous => $previous_version_number,] [ reason => $edit_reason, ] )
+	            [ previous => $previous_version_number,] [ reason => $edit_reason, ] )
 	
-	* `page` is the page being edited.
-	* `content` is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
-	* `reason` is the edit reason. Max 256 characters, will be truncated if longer. Optional.
-	* `previous` is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing. Optional.
+* `page` is the page being edited.
+
+* `content` is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
+
+* `reason` is the edit reason. Max 256 characters, will be truncated if longer. Optional.
+	
+* `previous` is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing. Optional.
 
 =item find_subreddits
 
     find_subreddits ( q => $query, [ sort => 'relevance' ,] 
-					[ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+                      [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
 
 Returns a list of Subreddit objects matching the search string `$query`. Optionally sort them by `sort`, which can be "relevance" or "activity".
 
@@ -1062,7 +1066,7 @@ Returns a list of Subreddit objects matching the search string `$query`. Optiona
 
     get_comment ( $fullname )
 
-Returns a [Comment](classes/comment) object for `$fullname`.
+Returns a Comment object for `$fullname`.
 
 =item get_flair_options
 
@@ -1073,33 +1077,34 @@ Return the flair options for either the post or the user provided.
 Returns a hash containing two keys:
 
 * `choices` is an array of hash references containing the flair options. Most important is `flair_template_id`, which is used to set the flair of a post or user with set_post_flair or set_user_flair. `flair_text` contains the text of the flair.
+
 * `current` is a hash of the post or user's existing flair.
 
 =item get_inbox 
 
     get_inbox ( [ view => MESSAGES_INBOX ,] [ limit => DEFAULT_LIMIT ,]
-	            [ before => undef ,] [ after => undef ,] )
+                [ before => undef ,] [ after => undef ,] )
 				
 Returns a list of [Message](classes/message) objects, where `view` is one of the MESSAGE [constants](constants). All arguments are optional. If all are omitted your default inbox will be returned-- what you would see if you went to reddit.com and clicked the mailbox icon.
 
-Checking your inbox via the API doesn't mark it as read. To do that you'll need to call [mark_inbox_read](http://redditclient.readthedocs.org/en/latest/main-methods/#mark_inbox_read).
+Checking your inbox via the API doesn't mark it as read. To do that you'll need to call `mark_inbox_read`: L<http://redditclient.readthedocs.org/en/latest/main-methods/#mark_inbox_read>
 
 =item get_link 
 
     get_link ( $fullname )
 
-Returns a [Link](classes/link) object for `$fullname`.
+Returns a Link object for `$fullname`.
 
 =item get_links
 
     get_links ( [ subreddit => undef ,] [ view => VIEW_DEFAULT ,] [ limit => DEFAULT_LIMIT ,]
-	            [ before => undef ,] [ after => undef ,] )
+                [ before => undef ,] [ after => undef ,] )
 
 Returns a list of [Link](classes/link) objects. All arguments are optional.
 
 `subreddit` can be a subreddit or multi (ex: "pics+funny"). If omitted, results from the user's front page will be returned-- i.e. what you would see if you visited reddit.com as that user. 
 
-`view` is a feed type [constant](constants)-- i.e. VIEW_HOT, VIEW_NEW, etc.
+`view` is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
 		
 fetch_links is an alias for get_links.
 
@@ -1118,11 +1123,11 @@ This version causes an extra request because it has to ask Reddit for the parent
     get_subreddit_comments ( [ subreddit => '' ,] [ view => VIEW_DEFAULT ,] [ limit => DEFAULT_LIMIT ,]
                              [ before => undef ,] [ after => undef ,]  )
 
-Returns a list of [Comment](classes/comment) objects from a subreddit or multi.
+Returns a list of Comment objects from a subreddit or multi.
 
 All arguments are optional. If subreddit is omitted the account's "front page" subreddits are returned (i.e. what you see when you visit reddit.com and are logged in). 
 
-`view` is a feed type [constant](constants)-- i.e. VIEW_HOT, VIEW_NEW, etc.
+`view` is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
 
 =item get_token
 
@@ -1137,9 +1142,9 @@ Get an Oauth token from Reddit. This is analogous to the old login function, and
 			   
 Get information about a user, where `view` is one of the [user constants](constants): overview, comments, submitted, gilded, upvoted, downvoted, hidden, or saved. Defaults to overview, which shows the user's most recent comments and posts.
 
-Note that if you try to get the upvoted, downvoted, hidden, or saved activity for a user other than yourself, Reddit will return a 403 error, so be sure to [wrap requests in a try/catch](http://redditclient.readthedocs.org/en/latest/examples/#catch-exceptions) if there's any chance that might happen. (Of course, all requests should be wrapped in a try/catch anyway, the internet being an unpredictable place.)
+Note that if you try to get the upvoted, downvoted, hidden, or saved activity for a user other than yourself, Reddit will return a 403 error, so be sure to wrap requests in a try/catch (L<http://redditclient.readthedocs.org/en/latest/examples/#catch-exceptions>) if there's any chance that might happen. (Of course, all requests should be wrapped in a try/catch anyway, the internet being an unpredictable place.)
 
-The result can be a list of [Links](classes/link), [Comments](classes/comment), or a mix of both, depending on what `view` you requested. You can determine which is which by looking at the type property, which is "t1" for comments and "t3" for posts.
+The result can be a list of Links, Comments, or a mix of both, depending on what `view` you requested. You can determine which is which by looking at the type property, which is "t1" for comments and "t3" for posts.
 
 =item has_token
 
@@ -1164,17 +1169,26 @@ Returns a hash of information about `$fullname`. `$fullname` can be any of the 8
     list_subreddits ( [ view => SUBREDDITS_HOME ,] [ limit => DEFAULT_LIMIT ,]
                       [ before => undef ,] [ after => undef ,]  )
 
-Returns a list of subreddits, where `view` is one of the SUBREDDIT [constants](constants). 
+Returns a list of subreddits, where `view` is one of the SUBREDDIT constants. 
 
 An alias function is provided for each view type, which is the same as calling `list_subreddits` with the view already provided:
 
+=over
+
 * contrib_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+
 * home_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+
 * mod_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+
 * my_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+
 * new_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+
 * popular_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
 
+=back
+
 =item mark_inbox_read
 
     mark_inbox_read()
@@ -1185,7 +1199,7 @@ Mark everything in your inbox as read. May take some time to complete.
 
     me()
 
-Return an [Account](classes/account) object that contains information about the logged in account. Aside from static account information it contains the `has_mail` property, which will be true if there is anything in your inbox.
+Return an Account object that contains information about the logged in account. Aside from static account information it contains the `has_mail` property, which will be true if there is anything in your inbox.
 
 =item new 
 
@@ -1194,13 +1208,9 @@ Return an [Account](classes/account) object that contains information about the
 
 Instantiate a Reddit::Client object. Optionally get an Oauth token (analogous to logging in) at the same time. If any of the four optional arguments are used, all are required.
 
-`$user_agent` is always required, and should be something descriptive that uniquely identifies your app. The [API Rules](https://github.com/reddit/reddit/wiki/API#rules) says it should be
+`$user_agent` is always required, and should be something descriptive that uniquely identifies your app. The API Rules (L<https://github.com/reddit/reddit/wiki/API#rules>) say it should be "something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information".
 
->something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information
-
-It also includes this warning:
-
->**NEVER lie about your user-agent.** This includes spoofing popular browsers and spoofing other bots. We will ban liars with extreme prejudice.
+It also includes this warning: "**NEVER lie about your user-agent.** This includes spoofing popular browsers and spoofing other bots. We will ban liars with extreme prejudice."
 
 =item save 
 
@@ -1218,13 +1228,13 @@ Send a private message to `$username`. `$subject` is limited to 100 characters.
 
     set_post_flair ( subreddit => $subreddit, post_id => $post_id_or_fullname, flair_template_id => $flair_id )
 	
-Set the flair on a post. The 'flair_template_id' is acquired via [get_flair_options](main-methods/#get_flair_options).
+Set the flair on a post. The 'flair_template_id' is acquired via `get_flair_options`.
 
 =item set_user_flair
 
     set_user_flair ( subreddit => $subreddit, username => $username, flair_template_id => $flair_id )
 	
-Set the flair for a user. The 'flair_template_id' is acquired via [get_flair_options](/main-methods/#get_flair_options).
+Set the flair for a user. The 'flair_template_id' is acquired via `get_flair_options`.
 
 =item submit_comment 
 
@@ -1236,13 +1246,13 @@ Submit a comment under `$fullname`, which must be a post or comment. Returns ful
 
     submit_link ( subreddit => $subreddit, title => $title, url => $url, [ inbox_replies => 1 ] )
 
-Submit a link. Returns the fullname of the new post. If `inbox_replies` is set and is false, disable inbox replies for that post.
+Submit a link. Returns the fullname of the new post. If `inbox_replies` is defined and is false, disable inbox replies for that post.
 
 =item submit_text 
 
     submit_text ( subreddit => $subreddit, title => $title, text => $text, [ inbox_replies => 1 ] )
 
-Submit a text post. Returns the fullname of the new post. If `inbox_replies` is set and is false, disable inbox replies for that post.
+Submit a text post. Returns the fullname of the new post. If `inbox_replies` is defined and is false, disable inbox replies for that post.
 
 =item unhide 
 
@@ -1280,4 +1290,3 @@ BSD license
 
 =cut
 
-
