@@ -9,7 +9,7 @@ require Reddit::Client::Thing;
 use base   qw/Reddit::Client::Thing/;
 use fields qw/over18 header_img created_utc header_title header_size
               description display_name created url title subscribers
-              public_description/;
+              public_traffic public_description subreddit_type/;
 
 # thse functions are currently unavailable
 sub get_links {
